==> mastapy-14.0.0rc2.tar.gz: mastapy-14.0.0rc2/mastapy/_private/_internal/implicit/enum_with_selected_value/load_distribution_factor_methods.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.gears.gear_designs.conical import _1209
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import List, Type, Any, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_LoadDistributionFactorMethods")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_LoadDistributionFactorMethods",)


class EnumWithSelectedValue_LoadDistributionFactorMethods(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_LoadDistributionFactorMethods

    A specific implementation of 'EnumWithSelectedValue' for 'LoadDistributionFactorMethods' types.
    """

    __qualname__ = "LoadDistributionFactorMethods"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_LoadDistributionFactorMethods]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_LoadDistributionFactorMethods]",
    ) -> "_1209.LoadDistributionFactorMethods":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1209.LoadDistributionFactorMethods
        """
        return _1209.LoadDistributionFactorMethods

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_LoadDistributionFactorMethods]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1209.LoadDistributionFactorMethods.type_()

    @property
    def selected_value(self: "Self") -> "_1209.LoadDistributionFactorMethods":
        """mastapy._private.gears.gear_designs.conical.LoadDistributionFactorMethods

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1209.LoadDistributionFactorMethods]":
        """List[mastapy._private.gears.gear_designs.conical.LoadDistributionFactorMethods]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.0.3.post1.tar.gz: mastapy-14.0.3.post1/mastapy/_private/_internal/implicit/enum_with_selected_value/load_distribution_factor_methods.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.gears.gear_designs.conical import _1209

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_LoadDistributionFactorMethods")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_LoadDistributionFactorMethods",)


class EnumWithSelectedValue_LoadDistributionFactorMethods(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_LoadDistributionFactorMethods

    A specific implementation of 'EnumWithSelectedValue' for 'LoadDistributionFactorMethods' types.
    """

    __qualname__ = "LoadDistributionFactorMethods"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_LoadDistributionFactorMethods]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_LoadDistributionFactorMethods]",
    ) -> "_1209.LoadDistributionFactorMethods":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1209.LoadDistributionFactorMethods
        """
        return _1209.LoadDistributionFactorMethods

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_LoadDistributionFactorMethods]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1209.LoadDistributionFactorMethods.type_()

    @property
    def selected_value(self: "Self") -> "_1209.LoadDistributionFactorMethods":
        """mastapy.gears.gear_designs.conical.LoadDistributionFactorMethods

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1209.LoadDistributionFactorMethods]":
        """List[mastapy.gears.gear_designs.conical.LoadDistributionFactorMethods]

        Note:
            This property is readonly.
        """
        return None
